@@ -1,4 +1,3 @@
-/* $XdotOrg: lib/fontenc/src/encparse.c,v 1.6 2006/04/10 16:15:12 alanc Exp $ */
 /*
 Copyright (c) 1998-2001 by Juliusz Chroboczek
 
@@ -21,8 +20,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-/* $XFree86: xc/lib/font/fontfile/encparse.c,v 1.20tsi Exp $ */
-
 /* Parser for encoding files */
 
 /* This code assumes that we are using ASCII.  We don't use the ctype
@@ -37,17 +34,7 @@ THE SOFTWARE.
 #include <strings.h>
 #endif
 
-#ifndef FONTENC_NO_LIBFONT
-
-#include <X11/fonts/fntfilio.h>
-#include <X11/fonts/fntfilst.h>
-
-#else
-
 #include <stdlib.h>
-#define xalloc(n) malloc(n)
-#define xrealloc(p, n) realloc(p, n)
-#define xfree(p) free(p)
 
 #include "zlib.h"
 typedef gzFile FontFilePtr;
@@ -58,8 +45,6 @@ typedef gzFile FontFilePtr;
 #define MAXFONTFILENAMELEN 1024
 #define MAXFONTNAMELEN 1024
 
-#endif
-
 #include <X11/fonts/fontenc.h>
 #include "fontencI.h"
 
@@ -437,14 +422,14 @@ setCode(unsigned from, unsigned to, unsigned row_size,
         return 0;
     if(*encsize == 0) {
         *encsize = (index < 256) ? 256 : 0x10000;
-        *enc = (unsigned short*)xalloc((*encsize) * sizeof(unsigned short));
+        *enc = malloc((*encsize) * sizeof(unsigned short));
         if(*enc == NULL) {
             *encsize = 0;
             return 1;
         }
     } else if(*encsize <= index) {
         *encsize = 0x10000;
-        if((newenc = (unsigned short*)xrealloc(enc, *encsize))==NULL)
+        if((newenc = realloc(enc, *encsize))==NULL)
             return 1;
         *enc = newenc;
     }
@@ -500,13 +485,12 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
     case EOF_LINE:
         goto error;
     case STARTENCODING_LINE:
-        encoding = (FontEncPtr)xalloc(sizeof(FontEncRec));
+        encoding = malloc(sizeof(FontEncRec));
         if(encoding == NULL)
             goto error;
-        encoding->name = (char*)xalloc(strlen(keyword_value)+1);
+        encoding->name = strdup(keyword_value);
         if(encoding->name == NULL)
             goto error;
-        strcpy(encoding->name, keyword_value);
         encoding->size = 256;
         encoding->row_size = 0;
         encoding->mappings = NULL;
@@ -523,10 +507,9 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
     case EOF_LINE: goto done;
     case ALIAS_LINE:
         if(numaliases < MAXALIASES) {
-            aliases[numaliases] = (char*)xalloc(strlen(keyword_value)+1);
+            aliases[numaliases] = strdup(keyword_value);
             if(aliases[numaliases] == NULL)
                 goto error;
-            strcpy(aliases[numaliases], keyword_value);
             numaliases++;
         }
         goto no_mapping;
@@ -542,7 +525,7 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
         if(headerOnly)
             goto done;
         if(!strcasecmp(keyword_value, "unicode")) {
-            mapping = (FontMapPtr)xalloc(sizeof(FontMapRec));
+            mapping = malloc(sizeof(FontMapRec));
             if(mapping == NULL)
                 goto error;
             mapping->type = FONT_ENCODING_UNICODE;
@@ -554,7 +537,7 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
             mapping->next = NULL;
             goto mapping;
         } else if(!strcasecmp(keyword_value, "cmap")) {
-            mapping = (FontMapPtr)xalloc(sizeof(FontMapRec));
+            mapping = malloc(sizeof(FontMapRec));
             if(mapping == NULL)
                 goto error;
             mapping->type = FONT_ENCODING_TRUETYPE;
@@ -566,7 +549,7 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
             mapping->next = NULL;
             goto mapping;
         } else if(!strcasecmp(keyword_value, "postscript")) {
-            mapping = (FontMapPtr)xalloc(sizeof(FontMapRec));
+            mapping = malloc(sizeof(FontMapRec));
             if(mapping == NULL)
                 goto error;
             mapping->type = FONT_ENCODING_POSTSCRIPT;
@@ -603,8 +586,7 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
     case ENDMAPPING_LINE:
         mapping->recode = FontEncSimpleRecode;
         mapping->name = FontEncUndefinedName;
-        mapping->client_data = sm =
-            (FontEncSimpleMapPtr)xalloc(sizeof(FontEncSimpleMapRec));
+        mapping->client_data = sm = malloc(sizeof(FontEncSimpleMapRec));
         if(sm == NULL)
             goto error;
         sm->row_size = encoding->row_size;
@@ -613,10 +595,9 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
 
             sm->first = first;
             sm->len=last-first+1;
-            newmap = 
-                (unsigned short*)xalloc(sm->len * sizeof(unsigned short));
+            newmap = malloc(sm->len * sizeof(unsigned short));
             if(newmap == NULL) {
-                xfree(sm);
+                free(sm);
                 mapping->client_data = sm = NULL;
                 goto error;
             }
@@ -685,20 +666,19 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
     case ENDMAPPING_LINE:
         mapping->recode = FontEncUndefinedRecode;
         mapping->name = FontEncSimpleName;
-        mapping->client_data = sn =
-            (FontEncSimpleNamePtr)xalloc(sizeof(FontEncSimpleNameRec));
+        mapping->client_data = sn = malloc(sizeof(FontEncSimpleNameRec));
         if(sn == NULL)
             goto error;
         if(first > last) {
-            xfree(sn);
+            free(sn);
             mapping->client_data = sn = NULL;
             goto error;
         }
         sn->first = first;
         sn->len = last - first + 1;
-        sn->map = (char**)xalloc(sn->len*sizeof(char*));
+        sn->map = malloc(sn->len*sizeof(char*));
         if(sn->map == NULL) {
-            xfree(sn);
+            free(sn);
             mapping->client_data = sn = NULL;
             goto error;
         }
@@ -712,14 +692,14 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
         if(value1 >= 0x10000) goto string_mapping;
         if(namsize == 0) {
             namsize = (value1) < 256 ? 256 : 0x10000;
-            nam = (char**)xalloc(namsize * sizeof(char*));
+            nam = malloc(namsize * sizeof(char*));
             if(nam == NULL) {
                 namsize=0;
                 goto error;
             }
         } else if(namsize <= value1) {
             namsize = 0x10000;
-            if((newnam = (char**)xrealloc(nam, namsize)) == NULL)
+            if((newnam = (char**)realloc(nam, namsize)) == NULL)
                 goto error;
             nam = newnam;
         }
@@ -736,23 +716,22 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
                 nam[i]=NULL;
             last = value1;
         }
-        nam[value1] = (char*)xalloc(strlen(keyword_value)+1);
+        nam[value1] = strdup(keyword_value);
         if(nam[value1] == NULL) {
             goto error;
         }
-        strcpy(nam[value1], keyword_value);
         goto string_mapping;
 
     default: goto string_mapping; /* ignore unknown lines */
     }
 
   done:
-    if(encsize) xfree(enc); encsize=0; enc = NULL;
-    if(namsize) xfree(nam); namsize=0; nam = NULL; /* don't free entries! */
+    if(encsize) free(enc); encsize=0; enc = NULL;
+    if(namsize) free(nam); namsize=0; nam = NULL; /* don't free entries! */
 
     encoding->aliases=NULL;
     if(numaliases) {
-        encoding->aliases = (char**)xalloc((numaliases+1)*sizeof(char*));
+        encoding->aliases = malloc((numaliases+1)*sizeof(char*));
         if(encoding->aliases == NULL)
             goto error;
         for(i=0; i<numaliases; i++)
@@ -763,30 +742,29 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
     return encoding;
 
 error:
-    if(encsize) xfree(enc); encsize=0;
+    if(encsize) free(enc); encsize=0;
     if(namsize) {
         for(i = first; i <= last; i++)
-            if(nam[i])
-                xfree(nam[i]);
-        xfree(nam);
+            free(nam[i]);
+        free(nam);
         namsize = 0;
     }
     if(mapping) {
-        if(mapping->client_data) xfree(mapping->client_data);
-        xfree(mapping);
+        free(mapping->client_data);
+        free(mapping);
     }
     if(encoding) {
 	FontMapPtr nextmap;
-	if (encoding->name) xfree(encoding->name);
+	free(encoding->name);
 	for (mapping = encoding->mappings; mapping; mapping = nextmap) {
-	    if (mapping->client_data) xfree(mapping->client_data);
+	    free(mapping->client_data);
 	    nextmap = mapping->next;
-	    xfree(mapping);
+	    free(mapping);
 	}
-	xfree(encoding);
+	free(encoding);
     }
     for(i = 0; i < numaliases; i++)
-        xfree(aliases[i]);
+        free(aliases[i]);
     /* We don't need to free sn and sm as they handled locally in the body.*/
     return NULL;
 }
@@ -799,10 +777,9 @@ FontEncDirectory(void)
     if(dir == NULL) {
         char *c = getenv("FONT_ENCODINGS_DIRECTORY");
         if(c) {
-            dir = malloc(strlen(c) + 1);
+            dir = strdup(c);
             if(!dir)
                 return NULL;
-            strcpy(dir, c);
         } else {
             dir = FONT_ENCODINGS_DIRECTORY;
         }
@@ -950,11 +927,10 @@ FontEncIdentify(const char *fileName)
         for(alias = encoding->aliases; *alias; alias++)
             numaliases++;
 
-    names = (char**)xalloc((numaliases+2)*sizeof(char*));
+    names = malloc((numaliases+2)*sizeof(char*));
     if(names == NULL) {
-        if(encoding->aliases)
-            xfree(encoding->aliases);
-        xfree(encoding);
+        free(encoding->aliases);
+        free(encoding);
         return NULL;
     }
 
@@ -965,8 +941,8 @@ FontEncIdentify(const char *fileName)
         *name = *alias;
 
     *name = NULL;
-    xfree(encoding->aliases);
-    xfree(encoding);
+    free(encoding->aliases);
+    free(encoding);
 
     return names;
 }
